@@ -1,7 +1,7 @@
 import { Op } from 'sequelize';
 import config from 'config';
 import { chunk, omit, omitBy } from 'lodash';
-import { VISIBILITY_STATUSES } from '@tamanu/constants';
+import { PORTAL_USER_STATUSES, VISIBILITY_STATUSES } from '@tamanu/constants';
 import { NOTE_RECORD_TYPES } from '@tamanu/constants/notes';
 import { InvalidParameterError } from '@tamanu/errors';
 import { log } from '@tamanu/shared/services/logging';
@@ -35,6 +35,7 @@ export const simpleUpdateModels = [
   'PatientContact',
   'IPSRequest',
   'Notification',
+  'PortalSurveyAssignment',
 ];
 
 // These ones need a little more attention.
@@ -53,6 +54,7 @@ export const specificUpdateModels = [
   'Note',
   'PatientFacility',
   'PatientFieldValue',
+  'PortalUser',
 ];
 
 // These columns should be omitted as we never want
@@ -96,7 +98,7 @@ function getMergedFieldsForUpdate(keepRecordValues = {}, unwantedRecordValues =
   };
 }
 
-const fieldReferencesPatient = (field) => field.references?.model === 'patients';
+const fieldReferencesPatient = field => field.references?.model === 'patients';
 const modelReferencesPatient = ([, model]) =>
   Object.values(model.getAttributes()).some(fieldReferencesPatient);
 
@@ -253,13 +255,16 @@ export async function mergePatientProgramRegistrations(models, keepPatientId, un
       });
 
       // Move conditions to the new patient program registration
-      await models.PatientProgramRegistrationCondition.update({
-        patientProgramRegistrationId: newRegistration.id,
-      }, {
-        where: {
-          patientProgramRegistrationId: unwantedRegistration.id,
+      await models.PatientProgramRegistrationCondition.update(
+        {
+          patientProgramRegistrationId: newRegistration.id,
         },
-      });
+        {
+          where: {
+            patientProgramRegistrationId: unwantedRegistration.id,
+          },
+        },
+      );
     }
 
     // Always destroy the unwanted registration
@@ -315,6 +320,44 @@ export async function mergePatientFieldValues(models, keepPatientId, unwantedPat
   return records;
 }
 
+export async function mergePortalUser(models, keepPatientId, unwantedPatientId) {
+  const existingUnwantedPortalUser = await models.PortalUser.findOne({
+    where: { patientId: unwantedPatientId },
+  });
+  if (!existingUnwantedPortalUser) return null;
+
+  const existingKeepPortalUser = await models.PortalUser.findOne({
+    where: { patientId: keepPatientId },
+  });
+
+  // If the keep patient doesn't have a portal account, transfer the unwanted patient's account
+  if (!existingKeepPortalUser) {
+    return existingUnwantedPortalUser.update({
+      patientId: keepPatientId,
+    });
+  }
+
+  const shouldKeepUnwantedAccount =
+    // If keep account is inactive but unwanted account is registered
+    (existingKeepPortalUser.status !== PORTAL_USER_STATUSES.REGISTERED &&
+      existingUnwantedPortalUser.status === PORTAL_USER_STATUSES.REGISTERED) ||
+    // If both have same status, prefer the one with more recent updates
+    (existingKeepPortalUser.status === existingUnwantedPortalUser.status &&
+      new Date(existingUnwantedPortalUser.updatedAt) > new Date(existingKeepPortalUser.updatedAt));
+
+  if (shouldKeepUnwantedAccount) {
+    // Delete the keep patient's account and transfer the unwanted patient's account
+    await existingKeepPortalUser.destroy();
+    return existingUnwantedPortalUser.update({
+      patientId: keepPatientId,
+    });
+  } else {
+    // Keep the existing account and delete the unwanted one
+    await existingUnwantedPortalUser.destroy();
+    return existingKeepPortalUser;
+  }
+}
+
 export async function reconcilePatientFacilities(models, keepPatientId, unwantedPatientId) {
   // This is a special case that helps with syncing the now-merged patient to any facilities
   // that track it
@@ -336,9 +379,9 @@ export async function reconcilePatientFacilities(models, keepPatientId, unwanted
   if (existingPatientFacilityRecords.length === 0) return [];
 
   const facilitiesTrackingPatient = [
-    ...new Set(existingPatientFacilityRecords.map((r) => r.facilityId)),
+    ...new Set(existingPatientFacilityRecords.map(r => r.facilityId)),
   ];
-  const newPatientFacilities = facilitiesTrackingPatient.map((facilityId) => ({
+  const newPatientFacilities = facilitiesTrackingPatient.map(facilityId => ({
     patientId: keepPatientId,
     facilityId,
   }));
@@ -380,6 +423,7 @@ async function updateDependentRecordsForResync(models, unwantedPatientId) {
   // Patient Death Data
   const patientDeathDataRecords = await models.PatientDeathData.findAll({
     where: { patientId: unwantedPatientId },
+
     attributes: ['id'],
   });
   await refreshMultiChildRecordsForSync(models.PatientDeathData, patientDeathDataRecords);
@@ -491,6 +535,12 @@ export async function mergePatient(
       updates.PatientProgramRegistration = patientProgramRegistrationUpdates.length;
     }
 
+    // Merge PortalUser records - ensure only one portal account per patient
+    const updatedPortalUser = await mergePortalUser(models, keepPatientId, unwantedPatientId);
+    if (updatedPortalUser) {
+      updates.PortalUser = 1;
+    }
+
     // Merge notes - these don't have a patient_id due to their polymorphic FK setup
     // so need to be handled slightly differently.
     const notesMerged = await mergeRecordsForModel(
